clear all
close all
rng(0); % initialize random number generator

tic

switch 1 % <- change this integer to select different data sets
    case 1 % waveforem
        %pi0 = 0.10;
        %pi1 = 0.25;
        pi0 = 0.15;
        pi1 = 0.05;
        x = dlmread('waveform.data');
        x_zero = x(find(x(:,end)==2),1:end-1);
        x_one = x(find(x(:,end)==1),1:end-1);
        N0 = 1000;
        N1 = 1000;
        x1 = [x_one(1:N1*(1-pi1),:); x_zero(1:N1*pi1,:)];
        x0 = [x_one(N1*(1-pi1)+1:N1*(1-pi1)+N0*pi0,:); x_zero(N1*pi1+1:N1*pi1+N0*(1-pi0),:)];
    case 2 % digits
        %pi0 = 0.10;
        %pi1 = 0.25;
        pi0 = 0.15;
        pi1 = 0.05;
        load mnist_38 % x, y contain mnist digit data
        x3 = x(1:end,find(y==3));
        x8 = x(1:end,find(y==8));
        N0 = 2000;
        N1 = 2000;
        x0 = [x3(:,1:N0*(1-pi0)) x8(:,1:N0*pi0)]';
        x1 = [x3(:,N0*(1-pi0)+1:N0*(1-pi0)+N1*pi1) x8(:,N0*pi0+1:N0*pi0+N1*(1-pi1))]';
    case 3 % nuclear
        load nuclear % z = time of flight in nanoseconds
        xg = x(1:64,find(z*10^9 < 5)); % gamma window
        xn = x(1:64,find((z*10^9 >= 45)&(z*10^9 < 55))); % neutron window        
        N0 = 3000;
        N1 = 3000;
        x0 = xg(:,1:N0)';
        x1 = xn(:,1:N1)';
        [pi1t_roc, pi0t_roc, bp_roc] = mpeROC(x1,x0);
        pi1_roc = pi1t_roc*(1-pi0t_roc)/(1 - pi0t_roc*pi1t_roc)
        pi0_roc = pi0t_roc*(1-pi1t_roc)/(1 - pi0t_roc*pi1t_roc)
        [pi1t_cpe, pi0t_cpe, bp_cpe] = mpeCPE(x1,x0);
        pi1_cpe = pi1t_cpe*(1-pi0t_cpe)/(1 - pi0t_cpe*pi1t_cpe)
        pi0_cpe = pi0t_cpe*(1-pi1t_cpe)/(1 - pi0t_cpe*pi1t_cpe)
        return

end

% true values of pi-tildes for comparison
pi1t = pi1/(1-pi0)
pi0t = pi0/(1-pi1)

for i=1:10 % mpe depends on random holdout split; average over different splits
    disp(['repetition ' num2str(i)])
    [pi1t_roc(i), pi0t_roc(i), bp_roc{i}] = mpeROC(x1,x0);
    %[pi1t_cpe(i), pi0t_cpe(i), bp_cpe{i}, maxprct(i), minprct(i)] = mpeCPE(x1,x0, pi1t,pi0t);
end
mpi1t_roc = median(pi1t_roc) % pi-tilde proportions
mpi0t_roc = median(pi0t_roc)
%mpi1t_cpe = median(pi1t_cpe)
%mpi0t_cpe = median(pi0t_cpe) 


% final estimates
pi1_roc = mpi1t_roc*(1-mpi0t_roc)/(1 - mpi0t_roc*mpi1t_roc)
pi0_roc = mpi0t_roc*(1-mpi1t_roc)/(1 - mpi0t_roc*mpi1t_roc)
%pi1_cpe = mpi1t_cpe*(1-mpi0t_cpe)/(1 - mpi0t_cpe*mpi1t_cpe)
%pi0_cpe = mpi0t_cpe*(1-mpi1t_cpe)/(1 - mpi0t_cpe*mpi1t_cpe)

toc